@@ -301,6 +301,8 @@
   # location parameters
   location_parameters <- switch(effects,
     fixed = setdiff(elements, c(auxiliary_parameters, random_parameters)),
+    grouplevel = ,
+    random_variance = ,
     random = intersect(setdiff(elements, auxiliary_parameters), random_parameters),
     setdiff(elements, auxiliary_parameters)
   )
@@ -323,8 +325,11 @@
   }
 
   elements <- switch(effects,
-    all = elements,
+    all = ,
+    full = elements,
     fixed = elements[!elements %in% random_parameters & !endsWith(elements, "random")],
+    grouplevel = ,
+    random_variance = ,
     random = elements[elements %in% random_parameters | endsWith(elements, "random")]
   )
 
@@ -490,7 +495,12 @@
 }
 
 
-.is_baysian_emmeans <- function(x) {
+.is_bayesian_marginaleffects <- function(x) {
+  !is.null(attributes(x)$posterior_draws)
+}
+
+
+.is_bayesian_emmeans <- function(x) {
   if (inherits(x, "emm_list")) {
     x <- x[[1]]
   }
@@ -499,21 +509,6 @@
 }
 
 
-.is_bayesian_model <- function(x, exclude = NULL) {
-  bayes_classes <- c(
-    "brmsfit", "stanfit", "MCMCglmm", "stanreg", "stanmvreg", "bmerMod",
-    "BFBayesFactor", "bamlss", "bayesx", "mcmc", "bcplm", "bayesQR", "BGGM",
-    "meta_random", "meta_fixed", "meta_bma", "blavaan", "blrm", "blmerMod",
-    "bglmerMod"
-  )
-  # if exclude is not NULL, remove elements in exclude from bayes_class
-  if (!is.null(exclude)) {
-    bayes_classes <- bayes_classes[!bayes_classes %in% exclude]
-  }
-  inherits(x, bayes_classes)
-}
-
-
 # safe conversion from factor to numeric
 .factor_to_numeric <- function(x, lowest = NULL) {
   if (is.data.frame(x)) {
