@@ -713,8 +713,11 @@ link_function.svyolr <- function(x, ...) {
 #' @export
 link_function.betareg <- function(x, what = c("mean", "precision"), ...) {
   what <- match.arg(what)
+
+  element_name <- .betareg_mean_element(x)
+
   switch(what,
-    mean = x$link$mean$linkfun,
+    mean = x$link[[element_name]]$linkfun,
     precision = x$link$precision$linkfun
   )
 }
