@@ -239,8 +239,12 @@ link_inverse.svy2lme <- link_inverse.lm
 #' @export
 link_inverse.betareg <- function(x, what = c("mean", "precision"), ...) {
   what <- match.arg(what)
-  switch(what,
-    mean = x$link$mean$linkinv,
+
+  element_name <- .betareg_mean_element(x)
+
+  switch(
+    what,
+    mean = x$link[[element_name]]$linkinv,
     precision = x$link$precision$linkinv
   )
 }
