@@ -4,12 +4,13 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-if (!requireNamespace("poorman", quietly = TRUE) ||
-  !requireNamespace("gt", quietly = TRUE)) {
+
+pkgs <- c("datawizard", "gt", "tinytable")
+if (!all(insight::check_if_installed(pkgs, quietly = TRUE))) {
+  knitr::opts_chunk$set(eval = FALSE)
+}
+if (getRversion() < "4.1.0") {
   knitr::opts_chunk$set(eval = FALSE)
-} else {
-  library(poorman)
-  library(gt)
 }
 
 ## ----warning=FALSE, message=FALSE---------------------------------------------
@@ -36,8 +37,9 @@ knitr::kable(df, format = "html")
 format_table(df)
 
 ## -----------------------------------------------------------------------------
-df %>%
-  mutate(p = format_p(p, stars = TRUE)) %>%
+library(datawizard) # for data_modify()
+df |>
+  data_modify(p = format_p(p, stars = TRUE)) |>
   format_table()
 
 ## ----eval=.Platform$OS.type == "windows"--------------------------------------
@@ -67,7 +69,17 @@ export_table(df, format = "md")
 export_table(df, format = "html")
 
 ## -----------------------------------------------------------------------------
-df %>%
-  format_table(ci_brackets = c("(", ")")) %>%
+df |>
+  format_table(ci_brackets = c("(", ")")) |>
   export_table(format = "html")
 
+## -----------------------------------------------------------------------------
+# By default, display() creates a markdown table
+display(df)
+
+## ----results='asis'-----------------------------------------------------------
+display(df, format = "html")
+
+## -----------------------------------------------------------------------------
+display(df, format = "tt")
+
