@@ -1,6 +1,6 @@
 skip_on_os("mac")
 skip_if_not(packageVersion("base") >= "4.2.0")
-skip_if_not_or_load_if_installed("epiR")
+skip_if_not_installed("epiR")
 
 
 dat <- matrix(c(13, 2163, 5, 3349), nrow = 2, byrow = TRUE)
@@ -8,7 +8,7 @@ rownames(dat) <- c("DF+", "DF-")
 colnames(dat) <- c("FUS+", "FUS-")
 
 # model
-m <- epi.2by2(
+m <- epiR::epi.2by2(
   dat = as.table(dat),
   method = "cohort.count",
   conf.level = 0.95,
