@@ -8,6 +8,7 @@ d <- mtcars
 m1 <- lm(mtcars$mpg ~ mtcars$hp * mtcars$cyl + poly(mtcars$drat, 2) / mtcars$disp)
 m2 <- lm(mtcars$mpg ~ d$hp * mtcars$cyl + poly(mtcars$drat, 2) / mtcars$disp)
 m3 <- lm(mpg ~ hp * cyl + poly(drat, 2) / disp, data = mtcars)
+m4 <- lm(mpg ~ hp * cyl + poly(drat, 2, raw = T) / disp, data = mtcars)
 
 test_that("find_formula-data1", {
   expect_warning(find_formula(m1))
@@ -26,3 +27,8 @@ test_that("find_formula-data3", {
     ignore_attr = TRUE
   )
 })
+
+test_that("find_formula-raw = T", {
+  expect_warning(find_formula(m4), regex = "Looks")
+  expect_silent(find_formula(m4, verbose = FALSE))
+})
