@@ -174,8 +174,8 @@ test_that("model_info-stanreg-glm", {
       is_chi2test = FALSE, is_ranktest = FALSE, is_levenetest = FALSE,
       is_variancetest = FALSE, is_xtab = FALSE, is_proptest = FALSE,
       is_binomtest = FALSE, is_ftest = FALSE, is_meta = FALSE, is_wiener = FALSE,
-      is_rtchoice = FALSE, link_function = "logit", family = "binomial", n_obs = 56L,
-      n_grouplevels = c(herd = 15L)
+      is_rtchoice = FALSE, is_mixture = FALSE, link_function = "logit",
+      family = "binomial", n_obs = 56L, n_grouplevels = c(herd = 15L)
     ),
     ignore_attr = TRUE
   )
@@ -197,8 +197,8 @@ test_that("model_info-stanreg-glm", {
       is_chi2test = FALSE, is_ranktest = FALSE, is_levenetest = FALSE,
       is_variancetest = FALSE, is_xtab = FALSE, is_proptest = FALSE,
       is_binomtest = FALSE, is_ftest = FALSE, is_meta = FALSE, is_wiener = FALSE,
-      is_rtchoice = FALSE, link_function = "identity", family = "gaussian", n_obs = 150L,
-      n_grouplevels = NULL
+      is_rtchoice = FALSE, is_mixture = FALSE, link_function = "identity",
+      family = "gaussian", n_obs = 150L, n_grouplevels = NULL
     ),
     ignore_attr = TRUE
   )
@@ -220,8 +220,8 @@ test_that("model_info-stanreg-glm", {
       is_chi2test = FALSE, is_ranktest = FALSE, is_levenetest = FALSE,
       is_variancetest = FALSE, is_xtab = FALSE, is_proptest = FALSE,
       is_binomtest = FALSE, is_ftest = FALSE, is_meta = FALSE, is_wiener = FALSE,
-      is_rtchoice = FALSE, link_function = "logit", family = "binomial", n_obs = 32L,
-      n_grouplevels = NULL
+      is_rtchoice = FALSE, is_mixture = FALSE, link_function = "logit",
+      family = "binomial", n_obs = 32L, n_grouplevels = NULL
     ),
     ignore_attr = TRUE
   )
